@@ -6,22 +6,24 @@ test_that("attributes_means", {
   model <- lm(Sepal.Length ~ Species + Sepal.Width, data = iris)
 
   estim <- suppressMessages(estimate_means(model, "Species", backend = "emmeans"))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "row.names", "class", "at", "by", "table_title", "table_footer",
-      "model", "response", "ci", "backend", "coef_name", "focal_terms",
+      "model", "response", "ci", "backend", "coef_name", "call", "focal_terms",
       "predict", "transform", "keep_iterations"
     )
   )
   estim <- suppressMessages(estimate_means(model, "Species", backend = "marginaleffects"))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "class", "row.names", "at", "by", "focal_terms", "adjusted_for",
       "predict", "estimate", "transform", "datagrid", "preserve_range",
       "model_info", "keep_iterations", "joint_test", "vcov", "table_title",
-      "table_footer", "model", "response", "ci", "backend", "coef_name"
+      "table_footer", "model", "response", "ci", "backend", "coef_name", "call"
     )
   )
 })
@@ -32,42 +34,55 @@ test_that("attributes_means, contrasts", {
   model <- lm(Sepal.Length ~ Species + Sepal.Width, data = iris)
 
   estim <- suppressMessages(estimate_contrasts(model, "Species", backend = "emmeans"))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "class", "row.names", "table_title", "table_footer",
-      "model", "response", "ci", "p_adjust", "backend", "predict",
+      "model", "response", "ci", "p_adjust", "backend", "call", "predict",
       "comparison", "contrast", "transform", "keep_iterations", "joint_test"
     )
   )
   estim <- suppressMessages(estimate_contrasts(model, "Species", backend = "marginaleffects"))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "row.names", "class", "table_title", "table_footer",
-      "model", "response", "ci", "p_adjust", "backend", "focal_terms",
+      "model", "response", "ci", "p_adjust", "backend", "call", "focal_terms",
       "adjusted_for", "predict", "comparison", "contrast", "estimate",
       "transform", "datagrid", "preserve_range", "coef_name", "model_info",
       "keep_iterations", "joint_test", "vcov"
     )
   )
-  estim <- suppressMessages(estimate_contrasts(model, "Species=c('setosa','virginica')", backend = "marginaleffects"))
+  estim <- suppressMessages(estimate_contrasts(
+    model,
+    "Species=c('setosa','virginica')",
+    backend = "marginaleffects"
+  ))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "row.names", "class", "table_title", "table_footer",
-      "model", "response", "ci", "p_adjust", "backend", "focal_terms",
+      "model", "response", "ci", "p_adjust", "backend", "call", "focal_terms",
       "adjusted_for", "predict", "comparison", "contrast", "estimate",
       "transform", "datagrid", "preserve_range", "coef_name", "model_info",
       "keep_iterations", "joint_test", "vcov"
     )
   )
-  estim <- suppressMessages(estimate_contrasts(model, "Species=c('setosa','virginica')", backend = "marginaleffects", estimate = "average"))
+  estim <- suppressMessages(estimate_contrasts(
+    model,
+    "Species=c('setosa','virginica')",
+    backend = "marginaleffects",
+    estimate = "average"
+  ))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "row.names", "class", "table_title", "table_footer",
-      "model", "response", "ci", "p_adjust", "backend", "focal_terms",
+      "model", "response", "ci", "p_adjust", "backend", "call", "focal_terms",
       "adjusted_for", "predict", "comparison", "contrast", "estimate",
       "transform", "datagrid", "preserve_range", "coef_name", "model_info",
       "contrast_filter", "keep_iterations", "joint_test","vcov"
@@ -81,21 +96,23 @@ test_that("attributes_means, slopes", {
   model <- lm(Sepal.Length ~ Species + Sepal.Width, data = iris)
 
   estim <- suppressMessages(estimate_slopes(model, "Sepal.Width", backend = "emmeans"))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "row.names", "class", "table_title", "table_footer",
-      "model", "response", "ci", "trend", "transform", "coef_name",
+      "model", "response", "ci", "call", "trend", "transform", "coef_name",
       "keep_iterations"
     )
   )
   estim <- suppressMessages(estimate_slopes(model, "Sepal.Width", backend = "marginaleffects"))
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
       "names", "class", "row.names", "trend", "p_adjust", "transform",
       "coef_name", "slope", "ci", "model_info", "keep_iterations",
-      "vcov", "table_title", "table_footer", "model", "response"
+      "vcov", "table_title", "table_footer", "model", "response", "call"
     )
   )
 })
@@ -109,6 +126,7 @@ test_that("attributes_means", {
     by = c("Species", "Petal.Width = [fivenum]"),
     preserve_range = FALSE
   )
+  # fmt: skip
   expect_named(
     attributes(estim),
     c(
