@@ -1,5 +1,5 @@
 skip_on_os(c("mac", "linux"))
-skip_if_not_installed("marginaleffects")
+skip_if_not_installed("marginaleffects", minimum_version = "0.29.0")
 skip_if_not_installed("withr")
 
 withr::with_environment(
